from session2.exercise2.cars.bmw import Bmw
from session2.exercise2.cars.mercedes import Mercedes
from session2.exercise2.cars.renault import Renault


bmw = Bmw()
mercedes = Mercedes()
renault = Renault()


