from session2.exercise1.count_letters_module import count_letters
from session2.exercise1.calculate_power_module import power
from session2.exercise1.calculate_square_root_module import square_root


print(count_letters())

print(power(2, 2))

print(square_root(16))
